<?php
session_start();
require_once 'scripts/config.php';
require_once 'scripts/auth_admin.php';

if (!isset($_SESSION['admin_id'])) {
    header("Location: admin_login.php");
    exit();
}

// Обработка выхода
if (isset($_GET['action']) && $_GET['action'] == 'logout') {
    logoutAdmin();
}

// Получение информации об администраторе
$admin_id = $_SESSION['admin_id'];
$stmt = $mysqli->prepare("SELECT name, email FROM admins WHERE id = ?");
$stmt->bind_param("i", $admin_id);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

// Определение активного модуля
$active_module = isset($_GET['module']) ? $_GET['module'] : 'dashboard';

?>

<!DOCTYPE html>
<html lang="ru">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Панель администратора</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.7.2/font/bootstrap-icons.css" rel="stylesheet">
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #f4f6f9;
        }
        .sidebar {
            min-height: 100vh;
            background-color: #343a40;
            color: #fff;
            padding-top: 20px;
        }
        .sidebar .nav-link {
            color: #ced4da;
            padding: 10px 20px;
        }
        .sidebar .nav-link:hover,
        .sidebar .nav-link.active {
            color: #fff;
            background-color: #495057;
        }
        .sidebar .nav-link i {
            margin-right: 10px;
        }
        .content {
            padding: 20px;
        }
        .logout-btn {
            margin-top: auto;
            padding: 10px 20px;
            background-color: #dc3545;
            color: #fff;
            text-decoration: none;
            text-align: center;
        }
        .logout-btn:hover {
            background-color: #c82333;
            color: #fff;
        }
    </style>
</head>
<body>
    <div class="container-fluid">
        <div class="row">
            <nav class="col-md-3 col-lg-2 d-md-block sidebar">
                <div class="position-sticky">
                    <ul class="nav flex-column">
                        <li class="nav-item">
                            <a class="nav-link <?php echo $active_module == 'dashboard' ? 'active' : ''; ?>" href="?module=admin_overview">
                                <i class="bi bi-speedometer2"></i> Дашборд
                            </a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link <?php echo $active_module == 'users' ? 'active' : ''; ?>" href="?module=users">
                                <i class="bi bi-people"></i> Пользователи
                            </a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link <?php echo $active_module == 'admin_tracks' ? 'active' : ''; ?>" href="?module=admin_tracks">
                                <i class="bi bi-music-note-list"></i> Треки
                            </a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link <?php echo $active_module == 'reports' ? 'active' : ''; ?>" href="?module=reports">
                                <i class="bi bi-file-earmark-text"></i> Отчеты
                            </a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link <?php echo $active_module == 'settings' ? 'active' : ''; ?>" href="?module=settings">
                                <i class="bi bi-gear"></i> Настройки
                            </a>
                        </li>
                    </ul>
                </div>
                <a href="?action=logout" class="logout-btn">
                    <i class="bi bi-box-arrow-right"></i> Выйти
                </a>
            </nav>

            <main class="col-md-9 ms-sm-auto col-lg-10 px-md-4">
                <div class="d-flex justify-content-between flex-wrap flex-md-nowrap align-items-center pt-3 pb-2 mb-3 border-bottom">
                    <h1 class="h2">Панель администратора</h1>
                </div>

                <div class="content">
                    <?php
                    switch ($active_module) {
                        case 'dashboard':
                            include 'modules/admin_overview.php';
                            break;
                        case 'users':
                            include 'modules/admin_users.php';
                            break;
                        case 'admin_tracks':
                            include 'modules/admin_tracks.php';
                            break;
                        case 'reports':
                            include 'modules/admin_reports.php';
                            break;
                        case 'settings':
                            include 'modules/admin_settings.php';
                            break;
                        default:
                            include 'modules/admin_overview.php';
                    }
                    ?>
                </div>
            </main>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
