<?php
require_once 'scripts/config.php';
require_once 'scripts/admin_functions.php';

// Получение треков на модерации
$tracks = getTracksOnModeration();

// Обработка действий модерации
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'];
    $trackId = $_POST['trackId'];

    switch ($action) {
        case 'approve':
            approveTrack($trackId);
            break;
        case 'reject':
            $comment = $_POST['comment'];
            rejectTrack($trackId, $comment);
            break;
        case 'request_changes':
            $comment = $_POST['comment'];
            requestChanges($trackId, $comment);
            break;
    }
}
?>

<h2>Модерация треков</h2>

<table class="table table-striped">
    <thead>
        <tr>
            <th>ID</th>
            <th>Название</th>
            <th>Артист</th>
            <th>Действия</th>
        </tr>
    </thead>
    <tbody>
        <?php foreach ($tracks as $track): ?>
            <tr>
                <td><?php echo $track['id']; ?></td>
                <td><?php echo htmlspecialchars($track['track_name']); ?></td>
                <td><?php echo htmlspecialchars($track['artist_name']); ?></td>
                <td>
                    <button class="btn btn-sm btn-success approve-track" data-track-id="<?php echo $track['id']; ?>">Одобрить</button>
                    <button class="btn btn-sm btn-warning request-changes" data-track-id="<?php echo $track['id']; ?>">Запросить изменения</button>
                    <button class="btn btn-sm btn-danger reject-track" data-track-id="<?php echo $track['id']; ?>">Отклонить</button>
                    <button class="btn btn-sm btn-info play-track" data-track-path="<?php echo htmlspecialchars($track['file_path']); ?>">Прослушать</button>
                </td>
            </tr>
        <?php endforeach; ?>
    </tbody>
</table>

<!-- Модальное окно для комментария -->
<div class="modal fade" id="commentModal" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">Оставить комментарий</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <form id="commentForm">
                    <input type="hidden" id="modalTrackId" name="trackId">
                    <input type="hidden" id="modalAction" name="action">
                    <div class="mb-3">
                        <label for="comment" class="form-label">Комментарий</label>
                        <textarea class="form-control" id="comment" name="comment" required></textarea>
                    </div>
                    <button type="submit" class="btn btn-primary">Отправить</button>
                </form>
            </div>
        </div>
    </div>
</div>

<script>
$(document).ready(function() {
    $('.approve-track').click(function() {
        const trackId = $(this).data('track-id');
        if (confirm('Вы уверены, что хотите одобрить этот трек?')) {
            $.post('scripts/admin_actions.php?action=approve_track', {trackId: trackId}, function(response) {
                if (response.status === 'success') {
                    alert('Трек одобрен');
                    location.reload();
                } else {
                    alert('Ошибка: ' + response.message);
                }
            });
        }
    });

    $('.request-changes, .reject-track').click(function() {
        const trackId = $(this).data('track-id');
        const action = $(this).hasClass('request-changes') ? 'request_changes' : 'reject';
        $('#modalTrackId').val(trackId);
        $('#modalAction').val(action);
        $('#commentModal').modal('show');
    });

    $('#commentForm').submit(function(e) {
        e.preventDefault();
        $.post('scripts/admin_actions.php?action=' + $('#modalAction').val(), $(this).serialize(), function(response) {
            if (response.status === 'success') {
                alert('Действие выполнено');
                $('#commentModal').modal('hide');
                location.reload();
            } else {
                alert('Ошибка: ' + response.message);
            }
        });
    });

    $('.play-track').click(function() {
        const audioSrc = $(this).data('track-path');
        const audio = new Audio(audioSrc);
        audio.play();
    });
});
</script>
