<?php
// Файл: scripts/admin_actions.php

require_once 'config.php';
require_once 'admin_functions.php';

if (isset($_GET['action'])) {
    switch ($_GET['action']) {
        case 'get_user_details':
            $user_id = $_GET['user_id'];
            $user = getUserDetails($user_id);
            echo generateUserDetailsHtml($user);
            break;

        case 'update_user':
            $user_id = $_POST['user_id'];
            $name = $_POST['name'];
            $email = $_POST['email'];
            $result = updateUser($user_id, $name, $email);
            echo json_encode($result);
            break;
    }
}

function getUserDetails($user_id) {
    global $mysqli;
    $stmt = $mysqli->prepare("SELECT * FROM users WHERE id = ?");
    $stmt->bind_param("i", $user_id);
    $stmt->execute();
    $result = $stmt->get_result();
    return $result->fetch_assoc();
}

function generateUserDetailsHtml($user) {
    $html = "<h3>Профиль пользователя</h3>";
    $html .= "<form id='editUserForm'>";
    $html .= "<input type='hidden' name='user_id' value='{$user['id']}'>";
    $html .= "<div class='mb-3'><label>Имя: <input type='text' name='name' value='{$user['name']}' class='form-control'></label></div>";
    $html .= "<div class='mb-3'><label>Email: <input type='email' name='email' value='{$user['email']}' class='form-control'></label></div>";
    $html .= "<button type='submit' class='btn btn-primary'>Сохранить изменения</button>";
    $html .= "</form>";

    $html .= "<h4 class='mt-4'>Активность пользователя</h4>";
    $html .= getUserActivity($user['id']);

    $html .= "<h4 class='mt-4'>Загруженные треки</h4>";
    $html .= getUserTracks($user['id']);

    return $html;
}

function getUserActivity($user_id) {
    global $mysqli;
    $stmt = $mysqli->prepare("SELECT * FROM user_actions WHERE user_id = ? ORDER BY id DESC LIMIT 10");
    $stmt->bind_param("i", $user_id);
    $stmt->execute();
    $result = $stmt->get_result();

    $html = "<ul>";
    while ($action = $result->fetch_assoc()) {
        $html .= "<li>{$action['action']} - {$action['created_at']}</li>";
    }
    $html .= "</ul>";

    return $html;
}

function getUserTracks($user_id) {
    global $mysqli;
    $stmt = $mysqli->prepare("SELECT * FROM tracks WHERE user_id = ? ORDER BY created_at DESC LIMIT 10");
    $stmt->bind_param("i", $user_id);
    $stmt->execute();
    $result = $stmt->get_result();

    $html = "<ul>";
    while ($track = $result->fetch_assoc()) {
        $html .= "<li>{$track['track_name']} - {$track['created_at']}</li>";
    }
    $html .= "</ul>";

    return $html;
}

function updateUser($user_id, $name, $email) {
    global $mysqli;
    $stmt = $mysqli->prepare("UPDATE users SET name = ?, email = ? WHERE id = ?");
    $stmt->bind_param("ssi", $name, $email, $user_id);

    if ($stmt->execute()) {
        return ['status' => 'success'];
    } else {
        return ['status' => 'error', 'message' => $mysqli->error];
    }
}
