<?php
// Файл: scripts/auth.php

session_start();
require_once 'config.php';

function registerUser($name, $phone, $password) {
    global $mysqli;

    // Проверка, существует ли пользователь с таким номером телефона
    $stmt = $mysqli->prepare("SELECT id FROM users WHERE phone = ?");
    $stmt->bind_param("s", $phone);
    $stmt->execute();
    $result = $stmt->get_result();
    if ($result->num_rows > 0) {
        return "Пользователь с таким номером телефона уже существует";
    }
    $stmt->close();

    // Хеширование пароля
    $hashed_password = password_hash($password, PASSWORD_DEFAULT);

    // Вставка нового пользователя в базу данных
    $stmt = $mysqli->prepare("INSERT INTO users (name, phone, password) VALUES (?, ?, ?)");
    $stmt->bind_param("sss", $name, $phone, $hashed_password);
    if ($stmt->execute()) {
        $user_id = $mysqli->insert_id;
        $_SESSION['user_id'] = $user_id;
        $_SESSION['user_name'] = $name;
        return $user_id;
    } else {
        return "Ошибка при регистрации пользователя";
    }
}

function loginUser($phone, $password) {
    global $mysqli;

    // Проверяем, существует ли пользователь с таким номером телефона
    $stmt = $mysqli->prepare("SELECT id, name, password FROM users WHERE phone = ?");
    $stmt->bind_param("s", $phone);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows === 0) {
        return "Пользователь с таким номером телефона не найден";
    }

    $user = $result->fetch_assoc();

    // Проверяем пароль
    if (password_verify($password, $user['password'])) {
        $_SESSION['user_id'] = $user['id'];
        $_SESSION['user_name'] = $user['name'];
        return $user['id'];
    } else {
        return "Неверный пароль";
    }
}

function isLoggedIn() {
    return isset($_SESSION['user_id']);
}

function logoutUser() {
    // Удаляем все данные сессии
    $_SESSION = array();

    // Если используются сессионные куки, удаляем и их
    if (ini_get("session.use_cookies")) {
        $params = session_get_cookie_params();
        setcookie(session_name(), '', time() - 42000,
            $params["path"], $params["domain"],
            $params["secure"], $params["httponly"]
        );
    }

    // Уничтожаем сессию
    session_destroy();
}

// Функция для получения информации о пользователе
function getUserInfo($user_id) {
    global $mysqli;
    $stmt = $mysqli->prepare("SELECT id, name, phone FROM users WHERE id = ?");
    $stmt->bind_param("i", $user_id);
    $stmt->execute();
    $result = $stmt->get_result();
    return $result->fetch_assoc();
}
