<?php
require_once 'config.php';

function registerAdmin($name, $email, $password) {
    global $mysqli;

    // Проверка, существует ли администратор с таким email
    $stmt = $mysqli->prepare("SELECT id FROM admins WHERE email = ?");
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $result = $stmt->get_result();
    if ($result->num_rows > 0) {
        return "Администратор с таким email уже существует";
    }
    $stmt->close();

    // Хеширование пароля
    $hashed_password = password_hash($password, PASSWORD_DEFAULT);

    // Вставка нового администратора в базу данных
    $stmt = $mysqli->prepare("INSERT INTO admins (name, email, password) VALUES (?, ?, ?)");
    $stmt->bind_param("sss", $name, $email, $hashed_password);
    if ($stmt->execute()) {
        $admin_id = $mysqli->insert_id;
        $_SESSION['admin_id'] = $admin_id;
        return true;
    } else {
        return "Ошибка при регистрации администратора";
    }
}

function loginAdmin($email, $password) {
    global $mysqli;

    // Проверяем, существует ли администратор с таким email
    $stmt = $mysqli->prepare("SELECT id, password FROM admins WHERE email = ?");
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows === 0) {
        return "Администратор с таким email не найден";
    }

    $admin = $result->fetch_assoc();

    // Проверяем пароль
    if (password_verify($password, $admin['password'])) {
        $_SESSION['admin_id'] = $admin['id'];
        return true;
    } else {
        return "Неверный пароль";
    }
}

function handleAdminAuth($action) {
    $error = '';
    if ($_SERVER["REQUEST_METHOD"] == "POST") {
        $email = trim($_POST['email']);
        $password = $_POST['password'];

        if (empty($email) || empty($password)) {
            $error = "Все поля должны быть заполнены";
        } elseif ($action == 'register' && strlen($password) < 8) {
            $error = "Пароль должен содержать минимум 8 символов";
        } else {
            if ($action == 'register') {
                $name = trim($_POST['name']);
                $result = registerAdmin($name, $email, $password);
            } else {
                $result = loginAdmin($email, $password);
            }

            if ($result === true) {
                header("Location: admin.php");
                exit();
            } else {
                $error = $result;
            }
        }
    }
    return $error;
}

function logoutAdmin() {
    unset($_SESSION['admin_id']);
    session_destroy();
    header("Location: admin_login.php");
    exit();
}
?>
